@@ -196,7 +196,7 @@ class Checker(object):
         """Process config and warn on each obsolete or deprecated entry."""
         for section, conf in config.items():
             if isinstance(conf, dict):
-                for k, v in conf.items():
+                for k in conf:
                     if k in self.obsolete:
                         warnings.warn('%r is obsolete. Use %r instead.\n'
                                       'section: [%s]' %
@@ -235,7 +235,7 @@ class Checker(object):
         for section, conf in app.config.items():
             is_path_section = section.startswith('/')
             if is_path_section and isinstance(conf, dict):
-                for k, v in conf.items():
+                for k in conf:
                     atoms = k.split('.')
                     if len(atoms) > 1:
                         if atoms[0] not in ns:
@@ -295,16 +295,9 @@ class Checker(object):
                'which does not match the expected type %r.')
 
         for section, conf in config.items():
-            if isinstance(conf, dict):
-                for k, v in conf.items():
-                    if v is not None:
-                        expected_type = self.known_config_types.get(k, None)
-                        vtype = type(v)
-                        if expected_type and vtype != expected_type:
-                            warnings.warn(msg % (k, section, vtype.__name__,
-                                                 expected_type.__name__))
-            else:
-                k, v = section, conf
+            if not isinstance(conf, dict):
+                conf = {section: conf}
+            for k, v in conf.items():
                 if v is not None:
                     expected_type = self.known_config_types.get(k, None)
                     vtype = type(v)
