@@ -6,16 +6,16 @@ import sys
 import time
 
 import six
+from six.moves import urllib
+from six.moves.http_client import BadStatusLine, HTTPConnection, NotConnected
+
 import pytest
 
+from cheroot.test import webtest
+
 import cherrypy
-from cherrypy._cpcompat import (
-    HTTPConnection, HTTPSConnection,
-    NotConnected, BadStatusLine,
-    ntob, tonative,
-    urlopen,
-)
-from cherrypy.test import helper, webtest
+from cherrypy._cpcompat import HTTPSConnection, ntob, tonative
+from cherrypy.test import helper
 
 
 timeout = 1
@@ -356,7 +356,7 @@ class PipelineTests(helper.CPWebCase):
         response = conn.response_class(conn.sock, method='GET')
         try:
             response.begin()
-        except:
+        except Exception:
             if not isinstance(sys.exc_info()[1],
                               (socket.error, BadStatusLine)):
                 self.fail("Writing to timed out socket didn't fail"
@@ -389,7 +389,7 @@ class PipelineTests(helper.CPWebCase):
         response = conn.response_class(conn.sock, method='GET')
         try:
             response.begin()
-        except:
+        except Exception:
             if not isinstance(sys.exc_info()[1],
                               (socket.error, BadStatusLine)):
                 self.fail("Writing to timed out socket didn't fail"
@@ -439,7 +439,7 @@ class PipelineTests(helper.CPWebCase):
             response = conn.response_class(conn.sock, method='GET')
             # there is a bug in python3 regarding the buffering of
             # ``conn.sock``. Until that bug get's fixed we will
-            # monkey patch the ``reponse`` instance.
+            # monkey patch the ``response`` instance.
             # https://bugs.python.org/issue23377
             if six.PY3:
                 response.fp = conn.sock.makefile('rb', 0)
@@ -723,8 +723,13 @@ class ConnectionTests(helper.CPWebCase):
         conn.close()
 
     def test_598(self):
-        remote_data_conn = urlopen('%s://%s:%s/one_megabyte_of_a/' %
-                                   (self.scheme, self.HOST, self.PORT,))
+        tmpl = '{scheme}://{host}:{port}/one_megabyte_of_a/'
+        url = tmpl.format(
+            scheme=self.scheme,
+            host=self.HOST,
+            port=self.PORT,
+        )
+        remote_data_conn = urllib.request.urlopen(url)
         buf = remote_data_conn.read(512)
         time.sleep(timeout * 0.6)
         remaining = (1024 * 1024) - 512
@@ -796,7 +801,8 @@ class LimitedRequestQueueTests(helper.CPWebCase):
                 conn.endheaders()
                 conns.append(conn)
 
-            # Now try a 16th conn, which should be closed by the server immediately.
+            # Now try a 16th conn, which should be closed by the
+            # server immediately.
             overflow_conn = self.HTTP_CONN(self.HOST, self.PORT)
             # Manually connect since httplib won't let us set a timeout
             for res in socket.getaddrinfo(self.HOST, self.PORT, 0,
@@ -810,7 +816,10 @@ class LimitedRequestQueueTests(helper.CPWebCase):
             overflow_conn.putrequest('GET', '/', skip_host=True)
             overflow_conn.putheader('Host', self.HOST)
             overflow_conn.endheaders()
-            response = overflow_conn.response_class(overflow_conn.sock, method='GET')
+            response = overflow_conn.response_class(
+                overflow_conn.sock,
+                method='GET',
+            )
             try:
                 response.begin()
             except socket.error as exc:
